<?php


namespace Intergo\Providers\Helpers;


class HashHelper
{
    const DEFAULT_ALGO = 'sha256';

    /**
     * Generate hash based on different algorithm.
     * Use sha1 for NON CRYPTOGRAPHIC info. Just to hash data to use it to match something. Not hashing passwords.
     * For password or other sensitive data use the self::DEFAULT_ALGO.
     *
     * @param $value
     * @param string $algo
     * @return false|string
     */
    public static function hash($value, $algo = 'sha1')
    {
        try {
            return hash($algo, $value);
        } catch (\Throwable $e)
        {
            return hash(self::DEFAULT_ALGO, $value);
        }
    }

    /**
     * Mask (hide) the value that is in text (string).
     *
     * @param string $value
     * @param string $text
     * @param string $replaceWith
     * @return string
     */
    public static function maskValue($value, string $text, string $replaceWith = '*******')
    {
        if (! empty($value) && is_string($value)) {
            $value = urlencode($value);
            return str_replace($value, $replaceWith, $text);
        }

        return $text;
    }
}
